//
// This code is part of https://developer.mescius.com/document-solutions/dot-net-word-api/demos.
// Copyright (c) MESCIUS inc. All rights reserved.
//
using System;
using System.IO;
using System.Drawing;
using System.Collections.Generic;
using System.Linq;
using GrapeCity.Documents.Word;

namespace DsWordWeb.Demos
{
    // This example shows how to add blur effect to shapes in a DOCX.
    public class BlurEffect
    {
        public GcWordDocument CreateDocx()
        {
            var doc = new GcWordDocument();

            // Shape Blur - direct:
            Paragraph p = doc.Body.Paragraphs.Add();
            Run run = p.GetRange().Runs.Add();
            Shape shape = run.GetRange().Shapes.Add(100, 100, GeometryType.Star4);
            shape.Fill.Type = FillType.Solid;
            shape.Fill.SolidFill.RGB = Color.Yellow;
            shape.Line.Width = 4;
            shape.Line.Fill.SolidFill.RGB = Color.Red;
            // apply 7 point blur effect to the shape
            shape.Effects.Blur.Radius = 7f;
            p.GetRange().Runs.Add("Shape Blur - direct.", doc.Styles[BuiltInStyleId.Strong]);

            // Shape Blur - shapes style:
            p = doc.Body.Paragraphs.Add();
            p.Style.ParagraphFormat.Spacing.SpaceBefore = 30;
            run = p.GetRange().Runs.Add();
            shape = run.GetRange().Shapes.Add(100, 100, GeometryType.Star4);
            shape.Fill.Type = FillType.Solid;
            shape.Fill.SolidFill.RGB = Color.Yellow;
            shape.Line.Width = 4;
            shape.Line.Fill.SolidFill.RGB = Color.Red;
            // apply 7 point blur effect to the shape
            var fmtEffect = doc.Theme.FormatScheme.Effects.Add();
            fmtEffect.Blur.Radius = 7f;
            //
            shape.Style.Effects.ThemeEffects = fmtEffect;
            p.GetRange().Runs.Add("Shape Blur - shapes style.", doc.Styles[BuiltInStyleId.Strong]);

            // Done:
            return doc;
        }
    }
}
